Welcome to mlf-core's documentation!
=====================================
.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   tutorial
   installation
   usage
   create
   list_info
   lint
   fix_artifact_paths
   bump_version
   sync
   config
   upgrade
   available_templates/available_templates
   github_support
   creating_releases
   contributing
   adding_new_templates
   faq
   changelog
   authors
   code_of_conduct

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
